@@ -3,11 +3,11 @@
 import unittest
 
 from wpull.url import URLInfo
-from wpull.urlfilter import (HTTPFilter, HTTPSOnlyFilter, BackwardDomainFilter,
+from wpull.urlfilter import (SchemeFilter, HTTPSOnlyFilter, BackwardDomainFilter,
                              HostnameFilter, RecursiveFilter, LevelFilter,
                              TriesFilter, ParentFilter, SpanHostsFilter,
                              RegexFilter, DirectoryFilter,
-                             BackwardFilenameFilter)
+                             BackwardFilenameFilter, FollowFTPFilter)
 
 
 class MockURLTableRecord(object):
@@ -25,10 +25,10 @@ class MockURLTableRecord(object):
 
 
 class TestURLFilter(unittest.TestCase):
-    def test_http_filter(self):
+    def test_scheme_filter(self):
         mock_record = MockURLTableRecord()
 
-        url_filter = HTTPFilter()
+        url_filter = SchemeFilter()
         self.assertTrue(url_filter.test(
             URLInfo.parse('http://example.net'),
             mock_record
@@ -37,6 +37,10 @@ class TestURLFilter(unittest.TestCase):
             URLInfo.parse('https://example.net'),
             mock_record
         ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('ftp://example.net'),
+            mock_record
+        ))
         self.assertFalse(url_filter.test(
             URLInfo.parse('mailto:user@example.com'),
             mock_record
@@ -67,6 +71,103 @@ class TestURLFilter(unittest.TestCase):
             mock_record
         ))
 
+    def test_follow_ftp_filter(self):
+        mock_record = MockURLTableRecord()
+        url_filter = FollowFTPFilter()
+
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('http://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('https://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('mailto:wolf@wolf.farts'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('ftp://wolf.farts/'),
+            mock_record
+        ))
+
+        mock_record.referrer = 'http://wolf.farts'
+
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('http://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('https://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('mailto:wolf@wolf.farts'),
+            mock_record
+        ))
+        self.assertFalse(url_filter.test(
+            URLInfo.parse('ftp://wolf.farts/'),
+            mock_record
+        ))
+
+        url_filter = FollowFTPFilter(follow=True)
+
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('http://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('https://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('mailto:wolf@wolf.farts'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('ftp://wolf.farts/'),
+            mock_record
+        ))
+
+        mock_record.referrer = 'ftp://wolf.farts'
+
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('http://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('https://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('mailto:wolf@wolf.farts'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('ftp://wolf.farts/'),
+            mock_record
+        ))
+
+        url_filter = FollowFTPFilter(follow=True)
+
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('http://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('https://wolf.farts/1'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('mailto:wolf@wolf.farts'),
+            mock_record
+        ))
+        self.assertTrue(url_filter.test(
+            URLInfo.parse('ftp://wolf.farts/'),
+            mock_record
+        ))
+
     def test_wget_domain_filter(self):
         url_filter = BackwardDomainFilter(
             accepted=['g.example.com', 'cdn.example.com', 'cdn.test'])
